pub struct CompleteEvent { /* private fields */ }Expand description
event in the db are composed of the EventData and the Metadata
Implementations
Sourceimpl CompleteEvent
impl CompleteEvent
Sourcepub const fn event_data(&self) -> &EventData
pub const fn event_data(&self) -> &EventData
public readonly getter for the EventData
Sourcepub fn full_event_data(&self) -> Result<EventData, SerdeError>
pub fn full_event_data(&self) -> Result<EventData, SerdeError>
Errors
Will return Err if Metadata cannot be de into json
Sourcepub fn from_command<C>(
command: &C,
previous_metadata: Option<&Metadata>,
) -> Result<Self, SerdeError>where
C: Command,
pub fn from_command<C>(
command: &C,
previous_metadata: Option<&Metadata>,
) -> Result<Self, SerdeError>where
C: Command,
Errors
Will return Err if Metadata cannot be de into json
Sourcepub fn from_event<E>(
event: &E,
previous_metadata: &Metadata,
) -> Result<Self, SerdeError>where
E: Event,
pub fn from_event<E>(
event: &E,
previous_metadata: &Metadata,
) -> Result<Self, SerdeError>where
E: Event,
Errors
Will return Err if Metadata cannot be serialized into json