pub struct ModelWithPosition<M> { /* private fields */ }Expand description
ModelWithPosition is a helper to add the position to any model
Implementations
Sourceimpl<M> ModelWithPosition<M>where
M: Dto,
impl<M> ModelWithPosition<M>where
M: Dto,
Sourcepub fn play_event(&mut self, event: &M::Event, position: Option<u64>)
pub fn play_event(&mut self, event: &M::Event, position: Option<u64>)
play one event to the current model to compute the next